@@ -2,9 +2,8 @@
 from ConfigParser import SafeConfigParser
 import os.path
 
-#tracker_cfg_file = os.path.expanduser('~/.config/tracker/tracker.cfg')
+tracker_cfg_file = os.path.expanduser('~/.config/tracker/tracker.cfg')
 backup_file = os.path.expanduser('~/.config/tracker/tracker.cfg.ORIG')
-tracker_cfg_file = os.path.abspath('tracker.cfg')
 
 if os.path.exists(backup_file):
   cfg = SafeConfigParser()
